@@ -10,8 +10,8 @@ forward     = sequence('C')
 back        = sequence('D')
 next_line   = sequence('E')
 prev_line   = sequence('F')
-goto_x      = sequence('H')
-goto        = sequence('G', 2)
+goto_x      = sequence('G')
+goto        = sequence('H', 2)
 erase       = sequence('J')
 erase_data  = erase
 erase_line  = sequence('K')
